Module installer

Module installer 

Enums

InstallerError

Functions

host_manifest
Generate the native messaging host manifest JSON.
host_manifest_path
Platform-specific native messaging host manifest location.
install
Install the native messaging host manifest for all supported Chromium browsers.
install_dir
Directory where the native host binary should be installed.
uninstall
Uninstall the native messaging host manifest.