Enums
Functions
- host_
manifest - Generate the native messaging host manifest JSON.
- host_
manifest_ path - Platform-specific native messaging host manifest location.
- install
- Install the native messaging host manifest for all supported Chromium browsers.
- install_
dir - Directory where the native host binary should be installed.
- uninstall
- Uninstall the native messaging host manifest.